package com.xkrs.utils;

import com.alibaba.fastjson.JSONObject;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;

/**
 * @author xkrs
 */
@Service
public class RestTemplateUtil {

    @Resource
    private RestTemplate restTemplate;

    /**
     * 以get方式请求第三方http接口 getForEntity
     * @param url
     * @return
     */
    public JSONObject doGetForEntity(String url) {
        ResponseEntity<JSONObject> responseEntity = restTemplate.getForEntity(url, JSONObject.class);
        return responseEntity.getBody();
    }

    /**
     * 以get方式请求第三方http接口 getForObject
     * 返回值返回的是响应体
     * @param url
     * @return
     */
    public JSONObject doGetForObject(String url) {
        JSONObject result = restTemplate.getForObject(url, JSONObject.class);
        return result;
    }

    /**
     * 以post方式请求第三方http接口 postForEntity
     * @param url
     * @return
     */
    public JSONObject doPostForEntity(String url) {
        //可设置请求参数
        JSONObject param = new JSONObject();
        param.put("userName","admin");
        param.put("ipAddress","");
        param.put("clientType","WINPC");
        ResponseEntity<JSONObject> responseEntity = restTemplate.postForEntity(url, param, JSONObject.class);
        return responseEntity.getBody();
    }

    /**
     * 以post方式请求第三方http接口 postForObject
     * @param url
     * @return
     */
    public JSONObject doPostForObject(String url,JSONObject param) {
        JSONObject result = restTemplate.postForObject(url, param, JSONObject.class);
        return result;
    }


    /**
     * exchange方法请求第三方http接口
     *
     */
    public JSONObject doExchange(String url, HttpHeaders httpHeaders, JSONObject param) {
        //创建请求对象
        HttpEntity<JSONObject> request = new HttpEntity<>(param,httpHeaders);
        //执行请求(请求路径，请求方式，请求体，响应体)
        ResponseEntity<JSONObject> responseEntity = restTemplate.exchange(url, HttpMethod.POST, request, JSONObject.class);
        return responseEntity.getBody();
    }

    /**
     * 发送第三方小米推送请求，向app端推送消息
     * @param url
     * @param httpHeaders
     * @param param
     */
    public void doPostMessageToApp(String url,HttpHeaders httpHeaders,JSONObject param) {
        //创建请求对象
        HttpEntity<JSONObject> request = new HttpEntity<>(param,httpHeaders);
        //执行请求(请求路径，请求方式，请求体，响应体)
        restTemplate.exchange(url, HttpMethod.POST, request, JSONObject.class);
    }

}
